R6 class holding the responses and design matrix used to fit a normal-block model.
Public fields
Ythe matrix of responses (rescaled column-wise if `scale = TRUE`)
Y_scalethe per-column standard deviation Y was divided by (all 1's if `scale = FALSE`)
Xthe matrix of covariates
X0the matrix of zero-inflation covariates, if applicable
formuladescribes the relationship between Y and X, and X0 if applicable, useful if not all of X's or X0's covariates should be used, should be formatted ~ X1 + X2... | Z1 + Z2... with the Normal formula before the | and the ZI formula after the |
nsample size
dnumber of covariates
d0number of zero-inflation covariates, if applicable
pnumber of variables
XtXm1inverse of XtX, useful for inference
XtYuseful for inference
npYtotal number of non zeros in Y
nYtotal number of non zeros for each column/variable in Y
zeroswhere are the zero in Y
zeros_barwhere are the non-zeros in Y
Methods
NormalBlockData$new()
Create a new [`NormalBlockData`] object.
Usage
NormalBlockData$new(Y, X, X0 = NULL, formula = NULL, scale = TRUE)Arguments
Ythe matrix of responses (called Y in the model).
Xdesign matrix (called X in the model).
X0zero-inflation design matrix, if applicable.
formuladescribes the relationship between Y and X, useful if not all of X's covariates should be used.
scalewhether to rescale each column of Y by its own standard deviation (no centering). Default TRUE – see the class-level documentation for the rationale and its limits.