Collection of Normal-Block Models over Cluster Counts and Sparsity Levels
Source:R/NormalBlockVarCollectionClustersSparsity.R
NormalBlockVarCollectionClustersSparsity.RdR6 class for a collection of normal-block models with different number of clusters (q) and different sparsity levels.
Super class
NormalBlockVarCollection -> NormalBlockVarCollectionClustersSparsity
Active bindings
q_listnumber of blocks
sparsitylist of penalties used for each q
who_am_Ia method to print what model is being fitted
Methods
NormalBlockVarCollectionClustersSparsity$new()
Create a new [`NormalBlockVarCollectionClustersSparsity`] object.
Usage
NormalBlockVarCollectionClustersSparsity$new(
mydata,
q_list,
zero_inflation = FALSE,
control = NB_control()
)NormalBlockVarCollectionClustersSparsity$get_model()
returns a collection of models corresponding to given q or one single model if penalty is also given
NormalBlockVarCollectionClustersSparsity$get_best_model()
Extract best model in the collection
Usage
NormalBlockVarCollectionClustersSparsity$get_best_model(
crit = c("ICL", "BIC", "EBIC")
)NormalBlockVarCollectionClustersSparsity$plot()
Display various outputs (goodness-of-fit criteria, robustness, diagnostic) associated with a collection of network fits (a [`Networkfamily`])
Usage
NormalBlockVarCollectionClustersSparsity$plot(
criterion = c("deviance", "ICL", "BIC", "EBIC"),
n_intervals = NULL
)