Skip to contents

R6 class for a normal-block model with known clustering.

Super class

NormalBlockVarBase -> NormalBlockVarKnownClusters

Active bindings

posterior_par

a list with the parameters of posterior distribution W | Y

entropy

Entropy of the conditional distribution

fitted

Y values predicted by the model, in Y's original units

who_am_I

a method to print what model is being fitted

Methods

Inherited methods


NormalBlockVarKnownClusters$new()

Create a new [`NormalBlockVarKnownClusters`] object.

Usage

NormalBlockVarKnownClusters$new(data, C, sparsity = 0, control = NB_control())

Arguments

data

object of NormalBlockVarData class, with responses and design matrix

C

clustering matrix C_jk = 1 if species j belongs to cluster k

sparsity

to apply on variance matrix when calling GLASSO

control

structured list of more specific parameters, to generate with NB_control

Returns

A new [`NormalBlockVarKnownClusters`] object


NormalBlockVarKnownClusters$clone()

The objects of this class are cloneable with this method.

Usage

NormalBlockVarKnownClusters$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.