Normal-Block Model with Unknown Clustering
Source:R/NormalBlockVarUnknownClusters.R
NormalBlockVarUnknownClusters.RdR6 class for a normal-block model with a fixed number of clusters (but unknown clustering).
Super class
NormalBlockVarBase -> NormalBlockVarUnknownClusters
Public fields
fixed_tauwhether tau should be fixed at clustering_init during optimization, useful for stability selection
Active bindings
model_para list with the matrices of the model parameters: B (covariates), dm1 (species variance), Omegaq (groups precision matrix))
nb_paramnumber of parameters in the model
var_para list with the matrices of the variational parameters: M (means), S (variances), tau (posterior group probabilities)
entropyEntropy of the conditional distribution
fittedY values predicted by the model, in Y's original units
who_am_Ia method to print what model is being fitted
Methods
Inherited methods
NormalBlockVarBase$best_of_inits()NormalBlockVarBase$candidates_merge()NormalBlockVarBase$candidates_split()NormalBlockVarBase$latent_network()NormalBlockVarBase$merge()NormalBlockVarBase$optimize()NormalBlockVarBase$plot()NormalBlockVarBase$plot_loglik()NormalBlockVarBase$plot_network()NormalBlockVarBase$predict()NormalBlockVarBase$print()NormalBlockVarBase$split()NormalBlockVarBase$update()NormalBlockVarBase$warm_start_from()
NormalBlockVarUnknownClusters$new()
Create a new [`NormalBlockVarUnknownClusters`] object.
Usage
NormalBlockVarUnknownClusters$new(
data,
q,
sparsity = 0,
control = NB_control()
)