Skip to contents

R6 class for a zero-inflated normal-block model with a known clustering.

Super class

NormalBlockVarBase -> ZINormalBlockVarKnownClusters

Active bindings

posterior_par

a list with the parameters of posterior distribution W | Y

entropy

Entropy of the conditional distribution

nb_param

number of parameters in the model

model_par

a list with model parameters: B (covariates), dm1 (species variance), Omegaq (groups precision matrix), kappa (zero-inflation probabilities)

fitted

Y values predicted by the model, in Y's original units

who_am_I

a method to print what model is being fitted

Methods

Inherited methods


ZINormalBlockVarKnownClusters$new()

Create a new [`ZINormalBlockVarKnownClusters`] object.

Usage

ZINormalBlockVarKnownClusters$new(
  data,
  C,
  sparsity = 0,
  control = NB_control()
)

Arguments

data

object of NormalBlockData class, with responses and design matrix

C

clustering matrix C_jk = 1 if species j belongs to cluster k

sparsity

to apply on variance matrix when calling GLASSO

control

structured list of more specific parameters, to generate with NB_control

Returns

A new [`ZINormalBlockVarKnownClusters`] object


ZINormalBlockVarKnownClusters$clone()

The objects of this class are cloneable with this method.

Usage

ZINormalBlockVarKnownClusters$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.