Skip to contents

R6 class for a zero-inflated normal-block model with a fixed number of clusters (but unknown clustering).

Super class

NormalBlockVarBase -> ZINormalBlockVarUnknownClusters

Public fields

fixed_tau

whether tau should be fixed at clustering_init during optimization, useful for stability selection

Active bindings

nb_param

number of parameters in the model

var_par

a list with variational parameters

model_par

a list with model parameters: B (covariates), dm1 (species variance), Omegaq (blocks precision matrix), kappa (zero-inflation probabilities)

entropy

Entropy of the conditional distribution

fitted

Y values predicted by the model, in Y's original units

who_am_I

a method to print what model is being fitted

Methods

Inherited methods


ZINormalBlockVarUnknownClusters$new()

Create a new [`ZINormalBlockVarUnknownClusters`] object.

Usage

ZINormalBlockVarUnknownClusters$new(
  data,
  q,
  sparsity = 0,
  control = NB_control()
)

Arguments

data

object of NormalBlockVarData class, with responses and design matrix

q

required number of groups

sparsity

to apply on variance matrix when calling GLASSO

control

structured list of more specific parameters

Returns

A new [`ZINormalBlockVarUnknownClusters`] object


ZINormalBlockVarUnknownClusters$clone()

The objects of this class are cloneable with this method.

Usage

ZINormalBlockVarUnknownClusters$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.