Zero-Inflated Normal-Block Model with Unknown Clustering
Source:R/ZINormalBlockVarUnknownClusters.R
ZINormalBlockVarUnknownClusters.RdR6 class for a zero-inflated normal-block model with a fixed number of clusters (but unknown clustering).
Super class
NormalBlockVarBase -> ZINormalBlockVarUnknownClusters
Public fields
fixed_tauwhether tau should be fixed at clustering_init during optimization, useful for stability selection
Active bindings
nb_paramnumber of parameters in the model
var_para list with variational parameters
model_para list with model parameters: B (covariates), dm1 (species variance), Omegaq (blocks precision matrix), kappa (zero-inflation probabilities)
entropyEntropy of the conditional distribution
fittedY values predicted by the model, in Y's original units
who_am_Ia method to print what model is being fitted
Methods
Inherited methods
NormalBlockVarBase$best_of_inits()NormalBlockVarBase$candidates_merge()NormalBlockVarBase$candidates_split()NormalBlockVarBase$latent_network()NormalBlockVarBase$merge()NormalBlockVarBase$optimize()NormalBlockVarBase$plot()NormalBlockVarBase$plot_loglik()NormalBlockVarBase$plot_network()NormalBlockVarBase$predict()NormalBlockVarBase$print()NormalBlockVarBase$split()NormalBlockVarBase$update()NormalBlockVarBase$warm_start_from()
ZINormalBlockVarUnknownClusters$new()
Create a new [`ZINormalBlockVarUnknownClusters`] object.
Usage
ZINormalBlockVarUnknownClusters$new(
data,
q,
sparsity = 0,
control = NB_control()
)